# Copyright (c) 2012 gocept gmbh & co. kg
# See also LICENSE.txt

"""lockcmd client the acquires locks remotely"""

from __future__ import unicode_literals, print_function
from .configparser import ListConfigParser
import argparse
import pkg_resources
import socket
import sys
import xmlrpclib


def cli(defaults):
    """Define and parse command line options."""
    argp = argparse.ArgumentParser(
        description='gocept.lockd client',
        version=pkg_resources.get_distribution('gocept.lockd').version)
    argp.add_argument('-F', '--configfile', metavar='FILE',
                      default=defaults['configfile'],
                      help='read settings from config file '
                      '(default: %(default)s)')
    argp.add_argument('-c', '--client', default=socket.gethostname(),
                      help='client name to acquire lock for '
                      '(default: %(default)s)')
    argp.add_argument('command', help='lock operation to perform',
                      choices=['lock', 'unlock'])
    argp.add_argument('resource', help='resource to lock (e.g., VM name)')
    return argp.parse_args()


def main(**defaults):
    """lockcmd console script entry point."""
    args = cli(defaults)
    config = ListConfigParser(args.configfile)
    lockd = xmlrpclib.ServerProxy(config.get('lockcmd', 'server'))
    cmd = getattr(lockd, args.command)
    try:
        cmd(args.resource, args.client)
    except xmlrpclib.Fault as exc:
        print('%s: cannot %s "%s"\n%s' % (
            sys.argv[0], args.command, args.resource, exc), file=sys.stderr)
        sys.exit(75)
    except xmlrpclib.ProtocolError as exc:
        print('%s: %s "%s" failed: %s %s' % (
            sys.argv[0], args.command, args.resource, exc.errcode, exc.errmsg),
            file=sys.stderr)
        sys.exit(69)
