# Copyright (c) 2012 gocept gmbh & co. kg
# See also LICENSE.txt

"""Specialized SafeConfigParser for list values"""

from __future__ import print_function, unicode_literals
import ConfigParser
import re


class ListConfigParser(ConfigParser.SafeConfigParser):
    """ConfigParser-like object with custom enhancements

    In addition to SafeConfigParser, ListConfigParser has a getlist()
    method that returns a list from a comma-separated value. It reads a
    mandatory configuration file from __init__ as a convenience
    enhancement.
    """

    def __init__(self, configfile=None):
        """Initialize SafeConfigParser object.

        If `configfile` is given, it is read and parsed during in the
        constructor.
        """
        ConfigParser.SafeConfigParser.__init__(self)
        if not configfile:
            return
        with open(configfile) as fobj:
            self.readfp(fobj)

    def getlist(self, section, option, separator=r'[,\s]+', default=None):
        """Retrieve list-valued configuration option.

        Return `option` from `section` as list. The value is split with
        `separator` as regular expression. If `default` is given, it is
        returned if no such option is found. Please note that `default`
        should be a list.
        """
        try:
            value = self.get(section, option)
        except ConfigParser.NoOptionError:
            if default is not None:
                return default
            raise
        return re.split(separator, value)
