# Copyright (c) 2012 gocept gmbh & co. kg
# See also LICENSE.txt
# pylint: disable-msg-cat=WCREFI

from __future__ import unicode_literals, print_function
from gocept.lockd.configparser import ListConfigParser
import contextlib
import tempfile
import unittest


@contextlib.contextmanager
def filecontent(content):
    """Run with path that points to a file containing `content`."""
    with tempfile.NamedTemporaryFile(prefix='fc', mode='w+') as tf:
        tf.write(content)
        tf.flush()
        tf.seek(0)
        yield tf.name


class ConfigParserTest(unittest.TestCase):

    def test_read_during_init(self):
        with filecontent("""\
[section]
key = value
""") as fname:
            cp = ListConfigParser(fname)
            self.assertEqual('value', cp.get('section', 'key'))

    def test_list_value(self):
        with filecontent("""\
[section]
key = value1, value2,
      value3
""") as fname:
            cp = ListConfigParser(fname)
            self.assertEqual(['value1', 'value2', 'value3'],
                             cp.getlist('section', 'key'))

    def test_list_default(self):
        with filecontent("""\
[section]
otherkey = value
""") as fname:
            cp = ListConfigParser(fname)
            self.assertEqual(['default'],
                             cp.getlist('section', 'key', default=['default']))
