# Copyright (c) 2012 gocept gmbh & co. kg
# See also LICENSE.txt
# pylint: disable-msg-cat=WCREFI

from __future__ import print_function, unicode_literals
from ..xmlrpc import ACLRequestHandler
import unittest
import mock


class ACLRequestHandlerTest(unittest.TestCase):

    @staticmethod
    def fake_access_filter(succeed):
        """Return an access filter that always succeeds or fails."""
        af = mock.MagicMock('gocept.lockd.access.AccessFilter')()
        af.check.return_value = succeed
        return af

    @mock.patch('BaseHTTPServer.BaseHTTPRequestHandler.log_message')
    @mock.patch('SimpleXMLRPCServer.SimpleXMLRPCServer')
    @mock.patch('socket.socket')
    def setUp(self, request, server, logger):
        self.server = server
        self.handler = ACLRequestHandler(request, '127.0.0.1', server)
        self.handler.is_rpc_path_valid = mock.MagicMock(
            name='is_rpc_path_valid')
        self.handler.log_message = logger

    def test_handler_should_try_filters_in_turn(self):
        self.server.access_filters = [self.fake_access_filter(True),
                                      self.fake_access_filter(True)]
        self.handler.do_POST()
        for access_filter in self.server.access_filters:
            access_filter.check.assert_called_with(self.handler)
            self.assertFalse(access_filter.decline.called)

    def test_handler_should_stop_after_first_failed(self):
        self.server.access_filters = [self.fake_access_filter(False),
                                      self.fake_access_filter(True)]
        self.handler.do_POST()
        self.server.access_filters[0].check.assert_called_with(self.handler)
        self.assertTrue(self.server.access_filters[0].decline.called)
        self.assertFalse(self.server.access_filters[1].check.called)
