# Copyright (c) 2012 gocept gmbh & co. kg
# See also LICENSE.txt

"""Low-level XML-RPC handling"""

import SimpleXMLRPCServer


class ACLRequestHandler(SimpleXMLRPCServer.SimpleXMLRPCRequestHandler):
    """Handle requests with with access control.

    If any of the server's access filters fail, decline the request.
    """
    # pylint: disable=C0103,R0904

    timeout = 900

    def do_POST(self):
        """Pass request to super class if access is allowed.

        If a server's access filter denies the request, it must also set
        the appropriate headers to signal this fact correctly to the
        client.
        """
        for access_filter in self.server.access_filters:
            if access_filter.check(self):
                continue
            access_filter.decline(self)
            return
        return SimpleXMLRPCServer.SimpleXMLRPCRequestHandler.do_POST(self)


class XMLRPCServer(SimpleXMLRPCServer.SimpleXMLRPCServer):
    """Single-socket server with automatic AF setting."""
    # pylint: disable=R0904

    allow_reuse_address = True

    def __init__(self, addrinfo):
        """Create server for socket specified by `addrinfo`."""
        self.address_family = addrinfo.family
        self.access_filters = []
        SimpleXMLRPCServer.SimpleXMLRPCServer.__init__(
            self, addrinfo.sockaddr, ACLRequestHandler, allow_none=True)
